@@ -3,15 +3,20 @@ import pyppeteer
 import random
 import time
 import string
-import atexit
 import requests
 import logging
+from threading import Thread
 
 # Import Detection From Stealth
 from .stealth import stealth
 
 from .get_acrawler import get_acrawler
 
+async_support = False
+def set_async():
+    global async_support
+    async_support = True
+
 class browser:
     def __init__(self, url, language='en', proxy=None, find_redirect=False, api_url=None, debug=False, newParams=False):
         self.url = url
@@ -47,19 +52,36 @@ class browser:
             'handleSIGTERM': False,
             'handleSIGHUP': False
         }
-
-        try:
-            self.loop = asyncio.new_event_loop()
+        
+        if async_support:
+            loop = asyncio.new_event_loop()
+            t = Thread(target=self.__start_background_loop, args=(loop, ), daemon=True)
+            t.start()
             if find_redirect:
-                self.loop.run_until_complete(self.find_redirect())
+                fut = asyncio.run_coroutine_threadsafe(self.find_redirect(), loop)
             elif newParams:
-                self.loop.run_until_complete(self.newParams())
+                fut = asyncio.run_coroutine_threadsafe(self.newParams(), loop)
             else:
-                self.loop.run_until_complete(self.start())
-        except:
-            self.loop.close()
+                fut = asyncio.run_coroutine_threadsafe(self.start(), loop)
+            fut.result()
+        else:
+            try:
+                self.loop = asyncio.new_event_loop()
+                if find_redirect:
+                    self.loop.run_until_complete(self.find_redirect())
+                elif newParams:
+                    self.loop.run_until_complete(self.newParams())
+                else:
+                    self.loop.run_until_complete(self.start())
+            except:
+                self.loop.close()
 
-    async def newParams(self):
+    def __start_background_loop(self, loop):
+        asyncio.set_event_loop(loop)
+        loop.run_forever()
+
+        
+    async def newParams(self) -> None:
         self.browser = await pyppeteer.launch(self.options)
         self.page = await self.browser.newPage()
         await self.page.goto("about:blank")
@@ -81,6 +103,8 @@ class browser:
         await self.browser.close()
         self.browser.process.communicate()
 
+        return 0
+
     async def start(self):
         self.browser = await pyppeteer.launch(self.options)
         self.page = await self.browser.newPage()
@@ -110,7 +134,6 @@ class browser:
             string.ascii_lowercase + string.ascii_uppercase + string.digits) for i in range(16))
 
         await self.page.evaluate("() => { " + get_acrawler() + " }")
-
         self.signature = await self.page.evaluate('''() => {
         var url = "''' + self.url + "&verifyFp=" + self.verifyFp + '''"
         var token = window.byted_acrawler.sign({url: url});
@@ -125,8 +148,8 @@ class browser:
                                  })
 
             self.data = await self.page.content()
-            self.data = json.loads(self.data.replace("</pre></body></html>", "").replace(
-                '<html><head></head><body><pre style="word-wrap: break-word; white-space: pre-wrap;">', ""))
+            #self.data = json.loads(self.data.replace("</pre></body></html>", "").replace(
+            #    '<html><head></head><body><pre style="word-wrap: break-word; white-space: pre-wrap;">', ""))
 
         await self.browser.close()
         self.browser.process.communicate()
@@ -183,4 +206,4 @@ class browser:
             return None
 
     def __get_js(self, proxy=None):
-        return requests.get("https://sf16-muse-va.ibytedtos.com/obj/rc-web-sdk-gcs/acrawler.js", proxies=self.__format_proxy(proxy)).text
+        return requests.get("https://sf16-muse-va.ibytedtos.com/obj/rc-web-sdk-gcs/acrawler.js", proxies=self.__format_proxy(proxy)).text
\ No newline at end of file
